@@ -1,7 +1,6 @@
 """Access the Daymet database for both single single pixel and gridded queries."""
 import io
 import itertools
-import warnings
 from typing import Callable, Dict, Iterable, List, Optional, Tuple, Union
 
 import async_retriever as ar
@@ -20,91 +19,15 @@ DEF_CRS = "epsg:4326"
 DATE_REQ = "%Y-%m-%dT%H:%M:%SZ"
 
 
-def get_byloc(
-    coords: Tuple[float, float],
-    dates: Union[Tuple[str, str], Union[int, List[int]]],
-    crs: str = DEF_CRS,
-    variables: Optional[Union[Iterable[str], str]] = None,
-    pet: bool = False,
-) -> pd.DataFrame:
-    """Get daily climate data from Daymet for a single point.
-
-    .. deprecated:: 0.9.0
-        Please use ``get_bycoords`` instead. This function will be removed in the future.
-
-    Parameters
-    ----------
-    coords : tuple
-        Longitude and latitude of the location of interest as a tuple (lon, lat)
-    dates : tuple or list
-        Either a tuple (start, end) or a list of years [YYYY, ...].
-    crs :  str, optional
-        The spatial reference of the input coordinates, defaults to epsg:4326
-    variables : str or list or tuple, optional
-        List of variables to be downloaded. The acceptable variables are:
-        ``tmin``, ``tmax``, ``prcp``, ``srad``, ``vp``, ``swe``, ``dayl``
-        Descriptions can be found `here <https://daymet.ornl.gov/overview>`__.
-        Defaults to None i.e., all the variables are downloaded.
-    pet : bool, optional
-        Whether to compute evapotranspiration based on
-        `FAO Penman-Monteith equation <http://www.fao.org/3/X0490E/x0490e06.htm>`__.
-        The default is False
-
-    Returns
-    -------
-    pandas.DataFrame
-        Daily climate data for a location.
-    """
-    msg = "Please use get_bycoords instead. This function will be removed in the future."
-    warnings.warn(msg, DeprecationWarning)
-
-    daymet = Daymet(variables, pet)
-    daymet.check_dates(dates)
-
-    if isinstance(dates, tuple):
-        dates_dict = daymet.dates_todict(dates)
-    else:
-        dates_dict = daymet.years_todict(dates)
-
-    if not (isinstance(coords, tuple) and len(coords) == 2):
-        raise InvalidInputType("coords", "tuple", "(lon, lat)")
-
-    lon, lat = ogcutils.match_crs([coords], crs, DEF_CRS)[0]
-
-    if not ((14.5 < lat < 52.0) or (-131.0 < lon < -53.0)):
-        raise InvalidInputRange(
-            "The location is outside the Daymet dataset. "
-            + "The acceptable range is: "
-            + "14.5 < lat < 52.0 and -131.0 < lon < -53.0"
-        )
-
-    params = {
-        "lat": f"{lat:.6f}",
-        "lon": f"{lon:.6f}",
-        "vars": ",".join(daymet.variables),
-        "format": "json",
-        **dates_dict,
-    }
-
-    r = ar.retrieve([ServiceURL().restful.daymet_point], "json", [{"params": params}])
-
-    clm = pd.DataFrame(r[0]["data"])
-    clm.index = pd.to_datetime(clm.year * 1000.0 + clm.yday, format="%Y%j")
-    clm = clm.drop(["year", "yday"], axis=1)
-
-    if pet:
-        clm = potential_et(clm, (lon, lat), alt_unit=True)
-    return clm
-
-
 def get_bycoords(
     coords: Tuple[float, float],
     dates: Union[Tuple[str, str], Union[int, List[int]]],
     crs: str = DEF_CRS,
     variables: Optional[Union[Iterable[str], str]] = None,
-    pet: bool = False,
     region: str = "na",
     time_scale: str = "daily",
+    pet: Optional[str] = None,
+    pet_params: Optional[Dict[str, float]] = None,
 ) -> xr.Dataset:
     """Get point-data from the Daymet database at 1-km resolution.
 
@@ -124,10 +47,6 @@ def get_bycoords(
         List of variables to be downloaded. The acceptable variables are:
         ``tmin``, ``tmax``, ``prcp``, ``srad``, ``vp``, ``swe``, ``dayl``
         Descriptions can be found `here <https://daymet.ornl.gov/overview>`__.
-    pet : bool
-        Whether to compute evapotranspiration based on
-        `FAO Penman-Monteith equation <http://www.fao.org/3/X0490E/x0490e06.htm>`__.
-        The default is False
     region : str, optional
         Target region in the US, defaults to ``na``. Acceptable values are:
 
@@ -136,8 +55,20 @@ def get_bycoords(
         * ``pr``: Puerto Rico
 
     time_scale : str, optional
-        Data time scale which can be daily, monthly (monthly summaries),
-        or annual (annual summaries). Defaults to daily.
+        Data time scale which can be ``daily``, ``monthly`` (monthly summaries),
+        or ``annual`` (annual summaries). Defaults to ``daily``.
+    pet : str, optional
+        Method for computing PET. Supported methods are
+        ``penman_monteith``, ``priestley_taylor``, ``hargreaves_samani``, and
+        None (don't compute PET). The ``penman_monteith`` method is based on
+        :footcite:t:`Allen_1998` assuming that soil heat flux density is zero.
+        The ``priestley_taylor`` method is based on
+        :footcite:t:`Priestley_1972` assuming that soil heat flux density is zero.
+        The ``hargreaves_samani`` method is based on :footcite:t:`Hargreaves_1982`.
+        Defaults to ``None``.
+    pet_params : dict, optional
+        Model-specific parameters as a dictionary that is passed to the PET function.
+        Defaults to ``None``.
 
     Returns
     -------
@@ -149,9 +80,13 @@ def get_bycoords(
     >>> import pydaymet as daymet
     >>> coords = (-1431147.7928, 318483.4618)
     >>> dates = ("2000-01-01", "2000-12-31")
-    >>> clm = daymet.get_bycoords(coords, dates, crs="epsg:3542", pet=True)
+    >>> clm = daymet.get_bycoords(coords, dates, crs="epsg:3542", pet="hargreaves_samani")
     >>> clm["pet (mm/day)"].mean()
-    3.497
+    3.713
+
+    References
+    ----------
+    .. footbibliography::
     """
     daymet = Daymet(variables, pet, time_scale, region)
     daymet.check_dates(dates)
@@ -191,8 +126,8 @@ def get_bycoords(
 
     clm = clm.set_index(pd.to_datetime(clm.index.strftime("%Y-%m-%d")))
 
-    if pet:
-        clm = potential_et(clm, coords, alt_unit=False)
+    if pet is not None:
+        clm = potential_et(clm, coords, method=pet, params=pet_params)
     return clm
 
 
@@ -201,9 +136,10 @@ def get_bygeom(
     dates: Union[Tuple[str, str], Union[int, List[int]]],
     crs: str = DEF_CRS,
     variables: Optional[Union[Iterable[str], str]] = None,
-    pet: bool = False,
     region: str = "na",
     time_scale: str = "daily",
+    pet: Optional[str] = None,
+    pet_params: Optional[Dict[str, float]] = None,
 ) -> xr.Dataset:
     """Get gridded data from the Daymet database at 1-km resolution.
 
@@ -219,10 +155,6 @@ def get_bygeom(
         List of variables to be downloaded. The acceptable variables are:
         ``tmin``, ``tmax``, ``prcp``, ``srad``, ``vp``, ``swe``, ``dayl``
         Descriptions can be found `here <https://daymet.ornl.gov/overview>`__.
-    pet : bool
-        Whether to compute evapotranspiration based on
-        `FAO Penman-Monteith equation <http://www.fao.org/3/X0490E/x0490e06.htm>`__.
-        The default is False
     region : str, optional
         Region in the US, defaults to na. Acceptable values are:
 
@@ -233,6 +165,18 @@ def get_bygeom(
     time_scale : str, optional
         Data time scale which can be daily, monthly (monthly average),
         or annual (annual average). Defaults to daily.
+    pet : str, optional
+        Method for computing PET. Supported methods are
+        ``penman_monteith``, ``priestley_taylor``, ``hargreaves_samani``, and
+        None (don't compute PET). The ``penman_monteith`` method is based on
+        :footcite:t:`Allen_1998` assuming that soil heat flux density is zero.
+        The ``priestley_taylor`` method is based on
+        :footcite:t:`Priestley_1972` assuming that soil heat flux density is zero.
+        The ``hargreaves_samani`` method is based on :footcite:t:`Hargreaves_1982`.
+        Defaults to ``None``.
+    pet_params : dict, optional
+        Model-specific parameters as a dictionary that is passed to the PET function.
+        Defaults to ``None``.
 
     Returns
     -------
@@ -249,6 +193,10 @@ def get_bygeom(
     >>> clm = daymet.get_bygeom(geometry, 2010, variables="tmin", time_scale="annual")
     >>> clm["tmin"].mean().compute().item()
     1.361
+
+    References
+    ----------
+    .. footbibliography::
     """
     daymet = Daymet(variables, pet, time_scale, region)
     daymet.check_dates(dates)
@@ -312,12 +260,12 @@ def get_bygeom(
     clm.attrs["transform"] = transform
     clm.attrs["res"] = (transform.a, transform.e)
 
-    if pet:
-        clm = potential_et(clm)
+    if pet is not None:
+        clm = potential_et(clm, method=pet, params=pet_params)
 
     if isinstance(clm, xr.Dataset):
         for v in clm:
-            clm[v].attrs["crs"] = crs
+            clm[v].attrs["crs"] = daymet_crs
             clm[v].attrs["nodatavals"] = (0.0,)
 
     return geoutils.xarray_geomask(clm, _geometry, DEF_CRS)
